<?php
/**
 * This file contain the list of functions which have default options.
 *
 * @version 4.0.0
 *
 * @package responsive-menu-pro
 */

/**
 * Function return the global settings default values.
 *
 * @version 4.0.0
 *
 * @return array List of options.
 */
function rmp_global_default_setting_options() {

    return [
        'rmp_custom_css'               => '',
        'rmp_dark_mode'                => 'off',
        'rmp_license_key'              => '',
        'menu_adjust_for_wp_admin_bar' => 'adjust',
        'rmp_external_files'           => 'on',
        'rmp_minify_scripts'           => 'on',
        'rmp_scripts_in_footer'        => 'on',
        'rmp_remove_fontawesome'       => 'off',
        'rmp_remove_glyphicon'         => 'off',
        'rmp_remove_dashicons'         => 'off',
        'rmp_remove_material_icons'    => 'off',
        'rmp_wp_footer_hook'           => 'off',
    ];
}

/**
 * Function return the multi device options.
 * Here, Add the option which you want to make the multi device.
 *
 * @version 4.0.0
 *
 * @return array List of options.
 */
function rmp_get_multi_device_options() {

    return [
        'menu_width'                           => '100',
        'menu_width_unit'                      => '%',
        'menu_font'                            => '',
        'menu_font_size'                       => '',
        'menu_font_size_unit'                  => 'px',
        'menu_item_background_colour'          => '',
        'menu_item_background_hover_colour'    => '#212121',
        'menu_link_colour'                     => '',
        'menu_link_hover_colour'               => '',
        'menu_links_height'                    => '',
        'menu_links_height_unit'               => 'px',
        'menu_links_line_height'               => '40',
        'menu_links_line_height_unit'          => 'px',
        'submenu_font'                         => '',
        'submenu_font_size'                    => '',
        'submenu_font_size_unit'               => '',
        'submenu_item_background_colour'       => '',
        'submenu_item_background_hover_colour' => '#212121',
        'submenu_link_colour'                  => '',
        'submenu_link_hover_colour'            => '',
        'submenu_links_height'                 => '',
        'submenu_links_height_unit'            => 'px',
        'submenu_links_line_height'            => '',
        'submenu_links_line_height_unit'       => 'px',
    ];
}

function rmp_animation_delay_options() {
    $time_options = [
        '100ms'  => '100ms',
        '200ms'  => '200ms',
        '300ms'  => '300ms',
        '400ms'  => '400ms',
        '500ms'  => '500ms',
        '600ms'  => '600ms',
        '700ms'  => '700ms',
        '800ms'  => '800ms',
        '900ms'  => '900ms',
        '1000ms' => '1000ms',
    ];

    return $time_options;
}

/**
 * Function to return the list of shortcut keys for menu open and close.
 *
 * @version 4.0.0
 *
 * @return array
 */
function rmp_get_menu_open_close_keys() {
    return [
        27 => 'Esc',
        13 => 'Enter',
        32 => 'Space',
        37 => 'Left',
        38 => 'Up',
        39 => 'Right',
        40 => 'Down',
    ];
}

function rmp_font_weight_options() {

    $unit_options = array(
        '100'     => '100',
        '200'     => '200',
        '300'     => '300',
        '400'     => '400',
        '500'     => '500',
        '600'     => '600',
        '700'     => '700',
        '800'     => '800',
        '900'     => '900',
        'normal'  => 'Normal',
        'bold'    => 'Bold',
        'bolder'  => 'Bolder',
        'lighter' => 'Lighter',
        'initial' => 'Initial',
        'inherit' => 'Inherit',
    );

    $unit_options = apply_filters('rmp_font_weight_options', $unit_options );

    return $unit_options;
}

function rmp_hamburger_type_animation_options() {

    $type = array(
        'off'        => __( 'Off', 'responsive-menu-pro' ),
        'boring'     => __( 'Boring','responsive-menu-pro' ),
        '3dx'        => __( '3DX','responsive-menu-pro' ),
        '3dx-r'      => __( '3DX Reverse','responsive-menu-pro' ),
        '3dy'        => __( '3DY','responsive-menu-pro' ),
        '3dy-r'      => __( '3DY Reverse','responsive-menu-pro' ),
        'arrow'      => __( 'Arrow','responsive-menu-pro' ),
        'arrow-r'    => __( 'Arrow Reverse','responsive-menu-pro' ),
        'arrowalt'   => __( 'Arrow Alt','responsive-menu-pro'),
        'arrowalt-r' => __( 'Arrow Alt Reverse','responsive-menu-pro' ),
        'collapse'   => 'Collapse',
        'collapse-r' => 'Collapse Reverse',
        'elastic'    => 'Elastic',
        'elastic-r'  => 'Elastic Reverse',
        'emphatic'   => 'Emphatic',
        'emphatic-r' => 'Emphatic Reverse',
        'minus'      => 'Minus',
        'slider'     => 'Slider',
        'slider-r'   => 'Slider Reverse',
        'spin'       => 'Spin',
        'spin-r'     => 'Spin Reverse',
        'spring'     => 'Spring',
        'spring-r'   => 'Spring Reverse',
        'stand'      => 'Stand',
        'stand-r'    => 'Stand Reverse',
        'squeeze'    => 'Squeeze',
        'vortex'     => 'Vortex',
        'vortex-r'   => 'Vortex Reverse',
    );

    $type = apply_filters('rmp_button_animation_type', $type );

    return $type;
}


/**
 * List of all available DashIcon classes.
 *
 * @since 1.0
 * @return array - Sorted list of icon classes
 */
function rmp_all_dash_icons() {

    $icons = array(
        'dash-f333' => 'dashicons-menu',
        'dash-f319' => 'dashicons-admin-site',
        'dash-f226' => 'dashicons-dashboard',
        'dash-f109' => 'dashicons-admin-post',
        'dash-f104' => 'dashicons-admin-media',
        'dash-f103' => 'dashicons-admin-links',
        'dash-f105' => 'dashicons-admin-page',
        'dash-f101' => 'dashicons-admin-comments',
        'dash-f100' => 'dashicons-admin-appearance',
        'dash-f106' => 'dashicons-admin-plugins',
        'dash-f110' => 'dashicons-admin-users',
        'dash-f107' => 'dashicons-admin-tools',
        'dash-f108' => 'dashicons-admin-settings',
        'dash-f112' => 'dashicons-admin-network',
        'dash-f102' => 'dashicons-admin-home',
        'dash-f111' => 'dashicons-admin-generic',
        'dash-f148' => 'dashicons-admin-collapse',
        'dash-f536' => 'dashicons-filter',
        'dash-f540' => 'dashicons-admin-editor',
        'dash-f541' => 'dashicons-admin-multisite',
        'dash-f119' => 'dashicons-welcome-write-blog',
        'dash-f133' => 'dashicons-welcome-add-page',
        'dash-f115' => 'dashicons-welcome-view-site',
        'dash-f116' => 'dashicons-welcome-widgets-menus',
        'dash-f117' => 'dashicons-welcome-comments',
        'dash-f118' => 'dashicons-welcome-learn-more',
        'dash-f123' => 'dashicons-format-aside',
        'dash-f128' => 'dashicons-format-image',
        'dash-f161' => 'dashicons-format-gallery',
        'dash-f126' => 'dashicons-format-video',
        'dash-f130' => 'dashicons-format-status',
        'dash-f122' => 'dashicons-format-quote',
        'dash-f125' => 'dashicons-format-chat',
        'dash-f127' => 'dashicons-format-audio',
        'dash-f306' => 'dashicons-camera',
        'dash-f232' => 'dashicons-images-alt',
        'dash-f233' => 'dashicons-images-alt2',
        'dash-f234' => 'dashicons-video-alt',
        'dash-f235' => 'dashicons-video-alt2',
        'dash-f236' => 'dashicons-video-alt3',
        'dash-f501' => 'dashicons-media-archive',
        'dash-f500' => 'dashicons-media-audio',
        'dash-f499' => 'dashicons-media-code',
        'dash-f498' => 'dashicons-media-default',
        'dash-f497' => 'dashicons-media-document',
        'dash-f496' => 'dashicons-media-interactive',
        'dash-f495' => 'dashicons-media-spreadsheet',
        'dash-f491' => 'dashicons-media-text',
        'dash-f490' => 'dashicons-media-video',
        'dash-f492' => 'dashicons-playlist-audio',
        'dash-f493' => 'dashicons-playlist-video',
        'dash-f522' => 'dashicons-controls-play',
        'dash-f523' => 'dashicons-controls-pause',
        'dash-f519' => 'dashicons-controls-forward',
        'dash-f517' => 'dashicons-controls-skipforward',
        'dash-f518' => 'dashicons-controls-back',
        'dash-f516' => 'dashicons-controls-skipback',
        'dash-f515' => 'dashicons-controls-repeat',
        'dash-f521' => 'dashicons-controls-volumeon',
        'dash-f520' => 'dashicons-controls-volumeoff',
        'dash-f165' => 'dashicons-image-crop',
        'dash-f531' => 'dashicons-image-rotate',
        'dash-f166' => 'dashicons-image-rotate-left',
        'dash-f167' => 'dashicons-image-rotate-right',
        'dash-f168' => 'dashicons-image-flip-vertical',
        'dash-f169' => 'dashicons-image-flip-horizontal',
        'dash-f533' => 'dashicons-image-filter',
        'dash-f171' => 'dashicons-undo',
        'dash-f172' => 'dashicons-redo',
        'dash-f200' => 'dashicons-editor-bold',
        'dash-f201' => 'dashicons-editor-italic',
        'dash-f203' => 'dashicons-editor-ul',
        'dash-f204' => 'dashicons-editor-ol',
        'dash-f205' => 'dashicons-editor-quote',
        'dash-f206' => 'dashicons-editor-alignleft',
        'dash-f207' => 'dashicons-editor-aligncenter',
        'dash-f208' => 'dashicons-editor-alignright',
        'dash-f209' => 'dashicons-editor-insertmore',
        'dash-f210' => 'dashicons-editor-spellcheck',
        'dash-f211' => 'dashicons-editor-expand',
        'dash-f506' => 'dashicons-editor-contract',
        'dash-f212' => 'dashicons-editor-kitchensink',
        'dash-f213' => 'dashicons-editor-underline',
        'dash-f214' => 'dashicons-editor-justify',
        'dash-f215' => 'dashicons-editor-textcolor',
        'dash-f216' => 'dashicons-editor-paste-word',
        'dash-f217' => 'dashicons-editor-paste-text',
        'dash-f218' => 'dashicons-editor-removeformatting',
        'dash-f219' => 'dashicons-editor-video',
        'dash-f220' => 'dashicons-editor-customchar',
        'dash-f221' => 'dashicons-editor-outdent',
        'dash-f222' => 'dashicons-editor-indent',
        'dash-f223' => 'dashicons-editor-help',
        'dash-f224' => 'dashicons-editor-strikethrough',
        'dash-f225' => 'dashicons-editor-unlink',
        'dash-f320' => 'dashicons-editor-rtl',
        'dash-f474' => 'dashicons-editor-break',
        'dash-f475' => 'dashicons-editor-code',
        'dash-f476' => 'dashicons-editor-paragraph',
        'dash-f535' => 'dashicons-editor-table',
        'dash-f135' => 'dashicons-align-left',
        'dash-f136' => 'dashicons-align-right',
        'dash-f134' => 'dashicons-align-center',
        'dash-f138' => 'dashicons-align-none',
        'dash-f160' => 'dashicons-lock',
        'dash-f528' => 'dashicons-unlock',
        'dash-f145' => 'dashicons-calendar',
        'dash-f508' => 'dashicons-calendar-alt',
        'dash-f177' => 'dashicons-visibility',
        'dash-f530' => 'dashicons-hidden',
        'dash-f173' => 'dashicons-post-status',
        'dash-f464' => 'dashicons-edit',
        'dash-f182' => 'dashicons-trash',
        'dash-f537' => 'dashicons-sticky',
        'dash-f504' => 'dashicons-external',
        'dash-f142' => 'dashicons-arrow-up',
        'dash-f140' => 'dashicons-arrow-down',
        'dash-f139' => 'dashicons-arrow-right',
        'dash-f141' => 'dashicons-arrow-left',
        'dash-f342' => 'dashicons-arrow-up-alt',
        'dash-f346' => 'dashicons-arrow-down-alt',
        'dash-f344' => 'dashicons-arrow-right-alt',
        'dash-f340' => 'dashicons-arrow-left-alt',
        'dash-f343' => 'dashicons-arrow-up-alt2',
        'dash-f347' => 'dashicons-arrow-down-alt2',
        'dash-f345' => 'dashicons-arrow-right-alt2',
        'dash-f341' => 'dashicons-arrow-left-alt2',
        'dash-f156' => 'dashicons-sort',
        'dash-f229' => 'dashicons-leftright',
        'dash-f503' => 'dashicons-randomize',
        'dash-f163' => 'dashicons-list-view',
        'dash-f164' => 'dashicons-exerpt-view',
        'dash-f509' => 'dashicons-grid-view',
        'dash-f237' => 'dashicons-share',
        'dash-f240' => 'dashicons-share-alt',
        'dash-f242' => 'dashicons-share-alt2',
        'dash-f301' => 'dashicons-twitter',
        'dash-f303' => 'dashicons-rss',
        'dash-f465' => 'dashicons-email',
        'dash-f466' => 'dashicons-email-alt',
        'dash-f304' => 'dashicons-facebook',
        'dash-f305' => 'dashicons-facebook-alt',
        'dash-f462' => 'dashicons-googleplus',
        'dash-f325' => 'dashicons-networking',
        'dash-f308' => 'dashicons-hammer',
        'dash-f309' => 'dashicons-art',
        'dash-f310' => 'dashicons-migrate',
        'dash-f311' => 'dashicons-performance',
        'dash-f483' => 'dashicons-universal-access',
        'dash-f507' => 'dashicons-universal-access-alt',
        'dash-f486' => 'dashicons-tickets',
        'dash-f484' => 'dashicons-nametag',
        'dash-f481' => 'dashicons-clipboard',
        'dash-f487' => 'dashicons-heart',
        'dash-f488' => 'dashicons-megaphone',
        'dash-f489' => 'dashicons-schedule',
        'dash-f120' => 'dashicons-wordpress',
        'dash-f324' => 'dashicons-wordpress-alt',
        'dash-f157' => 'dashicons-pressthis',
        'dash-f463' => 'dashicons-update',
        'dash-f180' => 'dashicons-screenoptions',
        'dash-f348' => 'dashicons-info',
        'dash-f174' => 'dashicons-cart',
        'dash-f175' => 'dashicons-feedback',
        'dash-f176' => 'dashicons-cloud',
        'dash-f326' => 'dashicons-translation',
        'dash-f323' => 'dashicons-tag',
        'dash-f318' => 'dashicons-category',
        'dash-f480' => 'dashicons-archive',
        'dash-f479' => 'dashicons-tagcloud',
        'dash-f478' => 'dashicons-text',
        'dash-f147' => 'dashicons-yes',
        'dash-f158' => 'dashicons-no',
        'dash-f335' => 'dashicons-no-alt',
        'dash-f132' => 'dashicons-plus',
        'dash-f502' => 'dashicons-plus-alt',
        'dash-f460' => 'dashicons-minus',
        'dash-f153' => 'dashicons-dismiss',
        'dash-f159' => 'dashicons-marker',
        'dash-f155' => 'dashicons-star-filled',
        'dash-f459' => 'dashicons-star-half',
        'dash-f154' => 'dashicons-star-empty',
        'dash-f227' => 'dashicons-flag',
        'dash-f534' => 'dashicons-warning',
        'dash-f230' => 'dashicons-location',
        'dash-f231' => 'dashicons-location-alt',
        'dash-f178' => 'dashicons-vault',
        'dash-f332' => 'dashicons-shield',
        'dash-f334' => 'dashicons-shield-alt',
        'dash-f468' => 'dashicons-sos',
        'dash-f179' => 'dashicons-search',
        'dash-f181' => 'dashicons-slides',
        'dash-f183' => 'dashicons-analytics',
        'dash-f184' => 'dashicons-chart-pie',
        'dash-f185' => 'dashicons-chart-bar',
        'dash-f238' => 'dashicons-chart-line',
        'dash-f239' => 'dashicons-chart-area',
        'dash-f307' => 'dashicons-groups',
        'dash-f338' => 'dashicons-businessman',
        'dash-f336' => 'dashicons-id',
        'dash-f337' => 'dashicons-id-alt',
        'dash-f312' => 'dashicons-products',
        'dash-f313' => 'dashicons-awards',
        'dash-f314' => 'dashicons-forms',
        'dash-f473' => 'dashicons-testimonial',
        'dash-f322' => 'dashicons-portfolio',
        'dash-f330' => 'dashicons-book',
        'dash-f331' => 'dashicons-book-alt',
        'dash-f316' => 'dashicons-download',
        'dash-f317' => 'dashicons-upload',
        'dash-f321' => 'dashicons-backup',
        'dash-f469' => 'dashicons-clock',
        'dash-f339' => 'dashicons-lightbulb',
        'dash-f482' => 'dashicons-microphone',
        'dash-f472' => 'dashicons-desktop',
        'dash-f471' => 'dashicons-tablet',
        'dash-f470' => 'dashicons-smartphone',
        'dash-f525' => 'dashicons-phone',
        'dash-f510' => 'dashicons-index-card',
        'dash-f511' => 'dashicons-carrot',
        'dash-f512' => 'dashicons-building',
        'dash-f513' => 'dashicons-store',
        'dash-f514' => 'dashicons-album',
        'dash-f527' => 'dashicons-palmtree',
        'dash-f524' => 'dashicons-tickets-alt',
        'dash-f526' => 'dashicons-money',
        'dash-f328' => 'dashicons-smiley',
        'dash-f529' => 'dashicons-thumbs-up',
        'dash-f542' => 'dashicons-thumbs-down',
        'dash-f538' => 'dashicons-layout',
        'dash-f452' => 'dashicons-buddicons-activity',
        'dash-f477' => 'dashicons-buddicons-bbpress-logo',
        'dash-f448' => 'dashicons-buddicons-buddypress-logo',
        'dash-f453' => 'dashicons-buddicons-community',
        'dash-f449' => 'dashicons-buddicons-forums',
        'dash-f454' => 'dashicons-buddicons-friends',
        'dash-f456' => 'dashicons-buddicons-groups',
        'dash-f457' => 'dashicons-buddicons-pm',
        'dash-f451' => 'dashicons-buddicons-replies',
        'dash-f450' => 'dashicons-buddicons-topics',
        'dash-f455' => 'dashicons-buddicons-tracking',
        'dash-f12c' => 'dashicons-editor-ol-rtl',
        'dash-f10c' => 'dashicons-editor-ltr',
        'dash-f10d' => 'dashicons-tide',
        'dash-f124' => 'dashicons-rest-api',
        'dash-f13a' => 'dashicons-code-standards',
        'dash-f11d' => 'dashicons-admin-site-alt',
        'dash-f11e' => 'dashicons-admin-site-alt2',
        'dash-f11f' => 'dashicons-admin-site-alt3',
        'dash-f228' => 'dashicons-menu-alt',
        'dash-f329' => 'dashicons-menu-alt2',
        'dash-f349' => 'dashicons-menu-alt3',
        'dash-f12d' => 'dashicons-instagram',
        'dash-f12f' => 'dashicons-businesswoman',
        'dash-f12e' => 'dashicons-businessperson',
        'dash-f467' => 'dashicons-email-alt2',
        'dash-f12a' => 'dashicons-yes-alt',
        'dash-f129' => 'dashicons-camera-alt',
        'dash-f485' => 'dashicons-plugins-checked',
        'dash-f113' => 'dashicons-update-alt',
        'dash-f121' => 'dashicons-text-page',
    );

    $icons = apply_filters( "rmp_dashicons", $icons );

    krsort( $icons );

    return $icons;
}


/**
 * List of all available glyphicon  classes.
 *
 * @since 1.0
 * @return array - Sorted list of icon classes
 */
function rmp_all_glyph_icons() {


    $glyph = array(
        'glyph-2a'   => 'glyphicon-asterisk',
        'glyph-2b'   => 'glyphicon-plus',
        'glyph-20ac' => 'glyphicon-eur',
        'glyph-2212' => 'glyphicon-minus',
        'glyph-2601' => 'glyphicon-cloud',
        'glyph-2709' => 'glyphicon-envelope',
        'glyph-270f' => 'glyphicon-pencil',
        'glyph-e001' => 'glyphicon-glass',
        'glyph-e002' => 'glyphicon-music',
        'glyph-e003' => 'glyphicon-search',
        'glyph-e005' => 'glyphicon-heart',
        'glyph-e006' => 'glyphicon-star',
        'glyph-e007' => 'glyphicon-star-empty',
        'glyph-e008' => 'glyphicon-user',
        'glyph-e009' => 'glyphicon-film',
        'glyph-e010' => 'glyphicon-th-large',
        'glyph-e011' => 'glyphicon-th',
        'glyph-e012' => 'glyphicon-th-list',
        'glyph-e013' => 'glyphicon-ok',
        'glyph-e014' => 'glyphicon-remove',
        'glyph-e015' => 'glyphicon-zoom-in',
        'glyph-e016' => 'glyphicon-zoom-out',
        'glyph-e017' => 'glyphicon-off',
        'glyph-e018' => 'glyphicon-signal',
        'glyph-e019' => 'glyphicon-cog',
        'glyph-e020' => 'glyphicon-trash',
        'glyph-e021' => 'glyphicon-home',
        'glyph-e022' => 'glyphicon-file',
        'glyph-e023' => 'glyphicon-time',
        'glyph-e024' => 'glyphicon-road',
        'glyph-e025' => 'glyphicon-download-alt',
        'glyph-e026' => 'glyphicon-download',
        'glyph-e027' => 'glyphicon-upload',
        'glyph-e028' => 'glyphicon-inbox',
        'glyph-e029' => 'glyphicon-play-circle',
        'glyph-e030' => 'glyphicon-repeat',
        'glyph-e031' => 'glyphicon-refresh',
        'glyph-e032' => 'glyphicon-list-alt',
        'glyph-e033' => 'glyphicon-lock',
        'glyph-e034' => 'glyphicon-flag',
        'glyph-e035' => 'glyphicon-headphones',
        'glyph-e036' => 'glyphicon-volume-off',
        'glyph-e037' => 'glyphicon-volume-down',
        'glyph-e038' => 'glyphicon-volume-up',
        'glyph-e039' => 'glyphicon-qrcode',
        'glyph-e040' => 'glyphicon-barcode',
        'glyph-e041' => 'glyphicon-tag',
        'glyph-e042' => 'glyphicon-tags',
        'glyph-e043' => 'glyphicon-book',
        'glyph-e044' => 'glyphicon-bookmark',
        'glyph-e045' => 'glyphicon-print',
        'glyph-e046' => 'glyphicon-camera',
        'glyph-e047' => 'glyphicon-font',
        'glyph-e048' => 'glyphicon-bold',
        'glyph-e049' => 'glyphicon-italic',
        'glyph-e050' => 'glyphicon-text-height',
        'glyph-e051' => 'glyphicon-text-width',
        'glyph-e052' => 'glyphicon-align-left',
        'glyph-e053' => 'glyphicon-align-center',
        'glyph-e054' => 'glyphicon-align-right',
        'glyph-e055' => 'glyphicon-align-justify',
        'glyph-e056' => 'glyphicon-list',
        'glyph-e057' => 'glyphicon-indent-left',
        'glyph-e058' => 'glyphicon-indent-right',
        'glyph-e059' => 'glyphicon-facetime-video',
        'glyph-e060' => 'glyphicon-picture',
        'glyph-e062' => 'glyphicon-map-marker',
        'glyph-e063' => 'glyphicon-adjust',
        'glyph-e064' => 'glyphicon-tint',
        'glyph-e065' => 'glyphicon-edit',
        'glyph-e066' => 'glyphicon-share',
        'glyph-e067' => 'glyphicon-check',
        'glyph-e068' => 'glyphicon-move',
        'glyph-e069' => 'glyphicon-step-backward',
        'glyph-e070' => 'glyphicon-fast-backward',
        'glyph-e071' => 'glyphicon-backward',
        'glyph-e072' => 'glyphicon-play',
        'glyph-e073' => 'glyphicon-pause',
        'glyph-e074' => 'glyphicon-stop',
        'glyph-e075' => 'glyphicon-forward',
        'glyph-e076' => 'glyphicon-fast-forward',
        'glyph-e077' => 'glyphicon-step-forward',
        'glyph-e078' => 'glyphicon-eject',
        'glyph-e079' => 'glyphicon-chevron-left',
        'glyph-e080' => 'glyphicon-chevron-right',
        'glyph-e081' => 'glyphicon-plus-sign',
        'glyph-e082' => 'glyphicon-minus-sign',
        'glyph-e083' => 'glyphicon-remove-sign',
        'glyph-e084' => 'glyphicon-ok-sign',
        'glyph-e085' => 'glyphicon-question-sign',
        'glyph-e086' => 'glyphicon-info-sign',
        'glyph-e087' => 'glyphicon-screenshot',
        'glyph-e088' => 'glyphicon-remove-circle',
        'glyph-e089' => 'glyphicon-ok-circle',
        'glyph-e090' => 'glyphicon-ban-circle',
        'glyph-e091' => 'glyphicon-arrow-left',
        'glyph-e092' => 'glyphicon-arrow-right',
        'glyph-e093' => 'glyphicon-arrow-up',
        'glyph-e094' => 'glyphicon-arrow-down',
        'glyph-e095' => 'glyphicon-share-alt',
        'glyph-e096' => 'glyphicon-resize-full',
        'glyph-e097' => 'glyphicon-resize-small',
        'glyph-e101' => 'glyphicon-exclamation-sign',
        'glyph-e102' => 'glyphicon-gift',
        'glyph-e103' => 'glyphicon-leaf',
        'glyph-e104' => 'glyphicon-fire',
        'glyph-e105' => 'glyphicon-eye-open',
        'glyph-e106' => 'glyphicon-eye-close',
        'glyph-e107' => 'glyphicon-warning-sign',
        'glyph-e108' => 'glyphicon-plane',
        'glyph-e109' => 'glyphicon-calendar',
        'glyph-e110' => 'glyphicon-random',
        'glyph-e111' => 'glyphicon-comment',
        'glyph-e112' => 'glyphicon-magnet',
        'glyph-e113' => 'glyphicon-chevron-up',
        'glyph-e114' => 'glyphicon-chevron-down',
        'glyph-e115' => 'glyphicon-retweet',
        'glyph-e116' => 'glyphicon-shopping-cart',
        'glyph-e117' => 'glyphicon-folder-close',
        'glyph-e118' => 'glyphicon-folder-open',
        'glyph-e119' => 'glyphicon-resize-vertical',
        'glyph-e120' => 'glyphicon-resize-horizontal',
        'glyph-e121' => 'glyphicon-hdd',
        'glyph-e122' => 'glyphicon-bullhorn',
        'glyph-e123' => 'glyphicon-bell',
        'glyph-e124' => 'glyphicon-certificate',
        'glyph-e125' => 'glyphicon-thumbs-up',
        'glyph-e126' => 'glyphicon-thumbs-down',
        'glyph-e127' => 'glyphicon-hand-right',
        'glyph-e128' => 'glyphicon-hand-left',
        'glyph-e129' => 'glyphicon-hand-up',
        'glyph-e130' => 'glyphicon-hand-down',
        'glyph-e131' => 'glyphicon-circle-arrow-right',
        'glyph-e132' => 'glyphicon-circle-arrow-left',
        'glyph-e133' => 'glyphicon-circle-arrow-up',
        'glyph-e134' => 'glyphicon-circle-arrow-down',
        'glyph-e135' => 'glyphicon-globe',
        'glyph-e136' => 'glyphicon-wrench',
        'glyph-e137' => 'glyphicon-tasks',
        'glyph-e138' => 'glyphicon-filter',
        'glyph-e139' => 'glyphicon-briefcase',
        'glyph-e140' => 'glyphicon-fullscreen',
        'glyph-e141' => 'glyphicon-dashboard',
        'glyph-e142' => 'glyphicon-paperclip',
        'glyph-e143' => 'glyphicon-heart-empty',
        'glyph-e144' => 'glyphicon-link',
        'glyph-e145' => 'glyphicon-phone',
        'glyph-e146' => 'glyphicon-pushpin',
        'glyph-e148' => 'glyphicon-usd',
        'glyph-e149' => 'glyphicon-gbp',
        'glyph-e150' => 'glyphicon-sort',
        'glyph-e151' => 'glyphicon-sort-by-alphabet',
        'glyph-e152' => 'glyphicon-sort-by-alphabet-alt',
        'glyph-e153' => 'glyphicon-sort-by-order',
        'glyph-e154' => 'glyphicon-sort-by-order-alt',
        'glyph-e155' => 'glyphicon-sort-by-attributes',
        'glyph-e156' => 'glyphicon-sort-by-attributes-alt',
        'glyph-e157' => 'glyphicon-unchecked',
        'glyph-e158' => 'glyphicon-expand',
        'glyph-e159' => 'glyphicon-collapse-down',
        'glyph-e160' => 'glyphicon-collapse-up',
        'glyph-e161' => 'glyphicon-log-in',
        'glyph-e162' => 'glyphicon-flash',
        'glyph-e163' => 'glyphicon-log-out',
        'glyph-e164' => 'glyphicon-new-window',
        'glyph-e165' => 'glyphicon-record',
        'glyph-e166' => 'glyphicon-save',
        'glyph-e167' => 'glyphicon-open',
        'glyph-e168' => 'glyphicon-saved',
        'glyph-e169' => 'glyphicon-import',
        'glyph-e170' => 'glyphicon-export',
        'glyph-e171' => 'glyphicon-send',
        'glyph-e172' => 'glyphicon-floppy-disk',
        'glyph-e173' => 'glyphicon-floppy-saved',
        'glyph-e174' => 'glyphicon-floppy-remove',
        'glyph-e175' => 'glyphicon-floppy-save',
        'glyph-e176' => 'glyphicon-floppy-open',
        'glyph-e177' => 'glyphicon-credit-card',
        'glyph-e178' => 'glyphicon-transfer',
        'glyph-e179' => 'glyphicon-cutlery',
        'glyph-e180' => 'glyphicon-header',
        'glyph-e181' => 'glyphicon-compressed',
        'glyph-e182' => 'glyphicon-earphone',
        'glyph-e183' => 'glyphicon-phone-alt',
        'glyph-e184' => 'glyphicon-tower',
        'glyph-e185' => 'glyphicon-stats',
        'glyph-e186' => 'glyphicon-sd-video',
        'glyph-e187' => 'glyphicon-hd-video',
        'glyph-e188' => 'glyphicon-subtitles',
        'glyph-e189' => 'glyphicon-sound-stereo',
        'glyph-e190' => 'glyphicon-sound-dolby',
        'glyph-e191' => 'glyphicon-sound-5-1',
        'glyph-e192' => 'glyphicon-sound-6-1',
        'glyph-e193' => 'glyphicon-sound-7-1',
        'glyph-e194' => 'glyphicon-copyright-mark',
        'glyph-e195' => 'glyphicon-registration-mark',
        'glyph-e197' => 'glyphicon-cloud-download',
        'glyph-e198' => 'glyphicon-cloud-upload',
        'glyph-e199' => 'glyphicon-tree-conifer',
        'glyph-e200' => 'glyphicon-tree-deciduous',
        'glyph-e201' => 'glyphicon-cd',
        'glyph-e202' => 'glyphicon-save-file',
        'glyph-e203' => 'glyphicon-open-file',
        'glyph-e204' => 'glyphicon-level-up',
        'glyph-e205' => 'glyphicon-copy',
        'glyph-e206' => 'glyphicon-paste',
        'glyph-e209' => 'glyphicon-alert',
        'glyph-e210' => 'glyphicon-equalizer',
        'glyph-e211' => 'glyphicon-king',
        'glyph-e212' => 'glyphicon-queen',
        'glyph-e213' => 'glyphicon-pawn',
        'glyph-e214' => 'glyphicon-bishop',
        'glyph-e215' => 'glyphicon-knight',
        'glyph-e216' => 'glyphicon-baby-formula',
        'glyph-26fa' => 'glyphicon-tent',
        'glyph-e218' => 'glyphicon-blackboard',
        'glyph-e219' => 'glyphicon-bed',
        'glyph-f8ff' => 'glyphicon-apple',
        'glyph-e221' => 'glyphicon-erase',
        'glyph-231b' => 'glyphicon-hourglass',
        'glyph-e223' => 'glyphicon-lamp',
        'glyph-e224' => 'glyphicon-duplicate',
        'glyph-e225' => 'glyphicon-piggy-bank',
        'glyph-e226' => 'glyphicon-scissors',
        'glyph-e227' => 'glyphicon-bitcoin',
        'glyph-0a5'  => 'glyphicon-yen',
        'glyph-20bd' => 'glyphicon-ruble',
        'glyph-e230' => 'glyphicon-scale',
        'glyph-e231' => 'glyphicon-ice-lolly',
        'glyph-e232' => 'glyphicon-ice-lolly-tasted',
        'glyph-e233' => 'glyphicon-education',
        'glyph-e234' => 'glyphicon-option-horizontal',
        'glyph-e235' => 'glyphicon-option-vertical',
        'glyph-e236' => 'glyphicon-menu-hamburger',
        'glyph-e237' => 'glyphicon-modal-window',
        'glyph-e238' => 'glyphicon-oil',
        'glyph-e239' => 'glyphicon-grain',
        'glyph-e240' => 'glyphicon-sunglasses',
        'glyph-e241' => 'glyphicon-text-size',
        'glyph-e242' => 'glyphicon-text-color',
        'glyph-e243' => 'glyphicon-text-background',
        'glyph-e244' => 'glyphicon-object-align-top',
        'glyph-e245' => 'glyphicon-object-align-bottom',
        'glyph-e246' => 'glyphicon-object-align-horizontal',
        'glyph-e247' => 'glyphicon-object-align-left',
        'glyph-e248' => 'glyphicon-object-align-vertical',
        'glyph-e249' => 'glyphicon-object-align-right',
        'glyph-e250' => 'glyphicon-triangle-right',
        'glyph-e251' => 'glyphicon-triangle-left',
        'glyph-e252' => 'glyphicon-triangle-bottom',
        'glyph-e253' => 'glyphicon-triangle-top',
        'glyph-e254' => 'glyphicon-console',
        'glyph-e255' => 'glyphicon-superscript',
        'glyph-e256' => 'glyphicon-subscript',
        'glyph-e257' => 'glyphicon-menu-left',
        'glyph-e258' => 'glyphicon-menu-right',
        'glyph-e259' => 'glyphicon-menu-down',
        'glyph-e260' => 'glyphicon-menu-up',
    );

    $glyph = apply_filters( "rmp_glyphicon", $glyph );
    krsort( $glyph );

    return $glyph;
}

function rmp_all_mdi_icons() {

    $mdi = array(
        'mdi-e84d' => '3d_rotation',
        'mdi-eb3b' => 'ac_unit',
        'mdi-e190' => 'access_alarm',
        'mdi-e191' => 'access_alarms',
        'mdi-e192' => 'access_time',
        'mdi-e84e' => 'accessibility',
        'mdi-e914' => 'accessible',
        'mdi-e84f' => 'account_balance',
        'mdi-e850' => 'account_balance_wallet',
        'mdi-e851' => 'account_box',
        'mdi-e853' => 'account_circle',
        'mdi-e60e' => 'adb',
        'mdi-e145' => 'add',
        'mdi-e439' => 'add_a_photo',
        'mdi-e193' => 'add_alarm',
        'mdi-e003' => 'add_alert',
        'mdi-e146' => 'add_box',
        'mdi-e147' => 'add_circle',
        'mdi-e148' => 'add_circle_outline',
        'mdi-e567' => 'add_location',
        'mdi-e854' => 'add_shopping_cart',
        'mdi-e39d' => 'add_to_photos',
        'mdi-e05c' => 'add_to_queue',
        'mdi-e39e' => 'adjust',
        'mdi-e630' => 'airline_seat_flat',
        'mdi-e631' => 'airline_seat_flat_angled',
        'mdi-e632' => 'airline_seat_individual_suite',
        'mdi-e633' => 'airline_seat_legroom_extra',
        'mdi-e634' => 'airline_seat_legroom_normal',
        'mdi-e635' => 'airline_seat_legroom_reduced',
        'mdi-e636' => 'airline_seat_recline_extra',
        'mdi-e637' => 'airline_seat_recline_normal',
        'mdi-e195' => 'airplanemode_active',
        'mdi-e194' => 'airplanemode_inactive',
        'mdi-e055' => 'airplay',
        'mdi-eb3c' => 'airport_shuttle',
        'mdi-e855' => 'alarm',
        'mdi-e856' => 'alarm_add',
        'mdi-e857' => 'alarm_off',
        'mdi-e858' => 'alarm_on',
        'mdi-e019' => 'album',
        'mdi-eb3d' => 'all_inclusive',
        'mdi-e90b' => 'all_out',
        'mdi-e859' => 'android',
        'mdi-e85a' => 'announcement',
        'mdi-e5c3' => 'apps',
        'mdi-e149' => 'archive',
        'mdi-e5c4' => 'arrow_back',
        'mdi-e5db' => 'arrow_downward',
        'mdi-e5c5' => 'arrow_drop_down',
        'mdi-e5c6' => 'arrow_drop_down_circle',
        'mdi-e5c7' => 'arrow_drop_up',
        'mdi-e5c8' => 'arrow_forward',
        'mdi-e5d8' => 'arrow_upward',
        'mdi-e060' => 'art_track',
        'mdi-e85b' => 'aspect_ratio',
        'mdi-e85c' => 'assessment',
        'mdi-e85d' => 'assignment',
        'mdi-e85e' => 'assignment_ind',
        'mdi-e85f' => 'assignment_late',
        'mdi-e860' => 'assignment_return',
        'mdi-e861' => 'assignment_returned',
        'mdi-e862' => 'assignment_turned_in',
        'mdi-e39f' => 'assistant',
        'mdi-e3a0' => 'assistant_photo',
        'mdi-e226' => 'attach_file',
        'mdi-e227' => 'attach_money',
        'mdi-e2bc' => 'attachment',
        'mdi-e3a1' => 'audiotrack',
        'mdi-e863' => 'autorenew',
        'mdi-e01b' => 'av_timer',
        'mdi-e14a' => 'backspace',
        'mdi-e864' => 'backup',
        'mdi-e19c' => 'battery_alert',
        'mdi-e1a3' => 'battery_charging_full',
        'mdi-e1a4' => 'battery_full',
        'mdi-e1a5' => 'battery_std',
        'mdi-e1a6' => 'battery_unknown',
        'mdi-eb3e' => 'beach_access',
        'mdi-e52d' => 'beenhere',
        'mdi-e14b' => 'block',
        'mdi-e1a7' => 'bluetooth',
        'mdi-e60f' => 'bluetooth_audio',
        'mdi-e1a8' => 'bluetooth_connected',
        'mdi-e1a9' => 'bluetooth_disabled',
        'mdi-e1aa' => 'bluetooth_searching',
        'mdi-e3a2' => 'blur_circular',
        'mdi-e3a3' => 'blur_linear',
        'mdi-e3a4' => 'blur_off',
        'mdi-e3a5' => 'blur_on',
        'mdi-e865' => 'book',
        'mdi-e866' => 'bookmark',
        'mdi-e867' => 'bookmark_border',
        'mdi-e228' => 'border_all',
        'mdi-e229' => 'border_bottom',
        'mdi-e22a' => 'border_clear',
        'mdi-e22b' => 'border_color',
        'mdi-e22c' => 'border_horizontal',
        'mdi-e22d' => 'border_inner',
        'mdi-e22e' => 'border_left',
        'mdi-e22f' => 'border_outer',
        'mdi-e230' => 'border_right',
        'mdi-e231' => 'border_style',
        'mdi-e232' => 'border_top',
        'mdi-e233' => 'border_vertical',
        'mdi-e06b' => 'branding_watermark',
        'mdi-e3a6' => 'brightness_1',
        'mdi-e3a7' => 'brightness_2',
        'mdi-e3a8' => 'brightness_3',
        'mdi-e3a9' => 'brightness_4',
        'mdi-e3aa' => 'brightness_5',
        'mdi-e3ab' => 'brightness_6',
        'mdi-e3ac' => 'brightness_7',
        'mdi-e1ab' => 'brightness_auto',
        'mdi-e1ac' => 'brightness_high',
        'mdi-e1ad' => 'brightness_low',
        'mdi-e1ae' => 'brightness_medium',
        'mdi-e3ad' => 'broken_image',
        'mdi-e3ae' => 'brush',
        'mdi-e6dd' => 'bubble_chart',
        'mdi-e868' => 'bug_report',
        'mdi-e869' => 'build',
        'mdi-e43c' => 'burst_mode',
        'mdi-e0af' => 'business',
        'mdi-eb3f' => 'business_center',
        'mdi-e86a' => 'cached',
        'mdi-e7e9' => 'cake',
        'mdi-e0b0' => 'call',
        'mdi-e0b1' => 'call_end',
        'mdi-e0b2' => 'call_made',
        'mdi-e0b3' => 'call_merge',
        'mdi-e0b4' => 'call_missed',
        'mdi-e0e4' => 'call_missed_outgoing',
        'mdi-e0b5' => 'call_received',
        'mdi-e0b6' => 'call_split',
        'mdi-e06c' => 'call_to_action',
        'mdi-e3af' => 'camera',
        'mdi-e3b0' => 'camera_alt',
        'mdi-e8fc' => 'camera_enhance',
        'mdi-e3b1' => 'camera_front',
        'mdi-e3b2' => 'camera_rear',
        'mdi-e3b3' => 'camera_roll',
        'mdi-e5c9' => 'cancel',
        'mdi-e8f6' => 'card_giftcard',
        'mdi-e8f7' => 'card_membership',
        'mdi-e8f8' => 'card_travel',
        'mdi-eb40' => 'casino',
        'mdi-e307' => 'cast',
        'mdi-e308' => 'cast_connected',
        'mdi-e3b4' => 'center_focus_strong',
        'mdi-e3b5' => 'center_focus_weak',
        'mdi-e86b' => 'change_history',
        'mdi-e0b7' => 'chat',
        'mdi-e0ca' => 'chat_bubble',
        'mdi-e0cb' => 'chat_bubble_outline',
        'mdi-e5ca' => 'check',
        'mdi-e834' => 'check_box',
        'mdi-e835' => 'check_box_outline_blank',
        'mdi-e86c' => 'check_circle',
        'mdi-e5cb' => 'chevron_left',
        'mdi-e5cc' => 'chevron_right',
        'mdi-eb41' => 'child_care',
        'mdi-eb42' => 'child_friendly',
        'mdi-e86d' => 'chrome_reader_mode',
        'mdi-e86e' => 'class',
        'mdi-e14c' => 'clear',
        'mdi-e0b8' => 'clear_all',
        'mdi-e5cd' => 'close',
        'mdi-e01c' => 'closed_caption',
        'mdi-e2bd' => 'cloud',
        'mdi-e2be' => 'cloud_circle',
        'mdi-e2bf' => 'cloud_done',
        'mdi-e2c0' => 'cloud_download',
        'mdi-e2c1' => 'cloud_off',
        'mdi-e2c2' => 'cloud_queue',
        'mdi-e2c3' => 'cloud_upload',
        'mdi-e86f' => 'code',
        'mdi-e3b6' => 'collections',
        'mdi-e431' => 'collections_bookmark',
        'mdi-e3b7' => 'color_lens',
        'mdi-e3b8' => 'colorize',
        'mdi-e0b9' => 'comment',
        'mdi-e3b9' => 'compare',
        'mdi-e915' => 'compare_arrows',
        'mdi-e30a' => 'computer',
        'mdi-e638' => 'confirmation_number',
        'mdi-e0d0' => 'contact_mail',
        'mdi-e0cf' => 'contact_phone',
        'mdi-e0ba' => 'contacts',
        'mdi-e14d' => 'content_copy',
        'mdi-e14e' => 'content_cut',
        'mdi-e14f' => 'content_paste',
        'mdi-e3ba' => 'control_point',
        'mdi-e3bb' => 'control_point_duplicate',
        'mdi-e90c' => 'copyright',
        'mdi-e150' => 'create',
        'mdi-e2cc' => 'create_new_folder',
        'mdi-e870' => 'credit_card',
        'mdi-e3be' => 'crop',
        'mdi-e3bc' => 'crop_16_9',
        'mdi-e3bd' => 'crop_3_2',
        'mdi-e3bf' => 'crop_5_4',
        'mdi-e3c0' => 'crop_7_5',
        'mdi-e3c1' => 'crop_din',
        'mdi-e3c2' => 'crop_free',
        'mdi-e3c3' => 'crop_landscape',
        'mdi-e3c4' => 'crop_original',
        'mdi-e3c5' => 'crop_portrait',
        'mdi-e437' => 'crop_rotate',
        'mdi-e3c6' => 'crop_square',
        'mdi-e871' => 'dashboard',
        'mdi-e1af' => 'data_usage',
        'mdi-e916' => 'date_range',
        'mdi-e3c7' => 'dehaze',
        'mdi-e872' => 'delete',
        'mdi-e92b' => 'delete_forever',
        'mdi-e16c' => 'delete_sweep',
        'mdi-e873' => 'description',
        'mdi-e30b' => 'desktop_mac',
        'mdi-e30c' => 'desktop_windows',
        'mdi-e3c8' => 'details',
        'mdi-e30d' => 'developer_board',
        'mdi-e1b0' => 'developer_mode',
        'mdi-e335' => 'device_hub',
        'mdi-e1b1' => 'devices',
        'mdi-e337' => 'devices_other',
        'mdi-e0bb' => 'dialer_sip',
        'mdi-e0bc' => 'dialpad',
        'mdi-e52e' => 'directions',
        'mdi-e52f' => 'directions_bike',
        'mdi-e532' => 'directions_boat',
        'mdi-e530' => 'directions_bus',
        'mdi-e531' => 'directions_car',
        'mdi-e534' => 'directions_railway',
        'mdi-e566' => 'directions_run',
        'mdi-e533' => 'directions_subway',
        'mdi-e535' => 'directions_transit',
        'mdi-e536' => 'directions_walk',
        'mdi-e610' => 'disc_full',
        'mdi-e875' => 'dns',
        'mdi-e612' => 'do_not_disturb',
        'mdi-e611' => 'do_not_disturb_alt',
        'mdi-e643' => 'do_not_disturb_off',
        'mdi-e644' => 'do_not_disturb_on',
        'mdi-e30e' => 'dock',
        'mdi-e7ee' => 'domain',
        'mdi-e876' => 'done',
        'mdi-e877' => 'done_all',
        'mdi-e917' => 'donut_large',
        'mdi-e918' => 'donut_small',
        'mdi-e151' => 'drafts',
        'mdi-e25d' => 'drag_handle',
        'mdi-e613' => 'drive_eta',
        'mdi-e1b2' => 'dvr',
        'mdi-e3c9' => 'edit',
        'mdi-e568' => 'edit_location',
        'mdi-e8fb' => 'eject',
        'mdi-e0be' => 'email',
        'mdi-e63f' => 'enhanced_encryption',
        'mdi-e01d' => 'equalizer',
        'mdi-e000' => 'error',
        'mdi-e001' => 'error_outline',
        'mdi-e926' => 'euro_symbol',
        'mdi-e56d' => 'ev_station',
        'mdi-e878' => 'event',
        'mdi-e614' => 'event_available',
        'mdi-e615' => 'event_busy',
        'mdi-e616' => 'event_note',
        'mdi-e903' => 'event_seat',
        'mdi-e879' => 'exit_to_app',
        'mdi-e5ce' => 'expand_less',
        'mdi-e5cf' => 'expand_more',
        'mdi-e01e' => 'explicit',
        'mdi-e87a' => 'explore',
        'mdi-e3ca' => 'exposure',
        'mdi-e3cb' => 'exposure_neg_1',
        'mdi-e3cc' => 'exposure_neg_2',
        'mdi-e3cd' => 'exposure_plus_1',
        'mdi-e3ce' => 'exposure_plus_2',
        'mdi-e3cf' => 'exposure_zero',
        'mdi-e87b' => 'extension',
        'mdi-e87c' => 'face',
        'mdi-e01f' => 'fast_forward',
        'mdi-e020' => 'fast_rewind',
        'mdi-e87d' => 'favorite',
        'mdi-e87e' => 'favorite_border',
        'mdi-e06d' => 'featured_play_list',
        'mdi-e06e' => 'featured_video',
        'mdi-e87f' => 'feedback',
        'mdi-e05d' => 'fiber_dvr',
        'mdi-e061' => 'fiber_manual_record',
        'mdi-e05e' => 'fiber_new',
        'mdi-e06a' => 'fiber_pin',
        'mdi-e062' => 'fiber_smart_record',
        'mdi-e2c4' => 'file_download',
        'mdi-e2c6' => 'file_upload',
        'mdi-e3d3' => 'filter',
        'mdi-e3d0' => 'filter_1',
        'mdi-e3d1' => 'filter_2',
        'mdi-e3d2' => 'filter_3',
        'mdi-e3d4' => 'filter_4',
        'mdi-e3d5' => 'filter_5',
        'mdi-e3d6' => 'filter_6',
        'mdi-e3d7' => 'filter_7',
        'mdi-e3d8' => 'filter_8',
        'mdi-e3d9' => 'filter_9',
        'mdi-e3da' => 'filter_9_plus',
        'mdi-e3db' => 'filter_b_and_w',
        'mdi-e3dc' => 'filter_center_focus',
        'mdi-e3dd' => 'filter_drama',
        'mdi-e3de' => 'filter_frames',
        'mdi-e3df' => 'filter_hdr',
        'mdi-e152' => 'filter_list',
        'mdi-e3e0' => 'filter_none',
        'mdi-e3e2' => 'filter_tilt_shift',
        'mdi-e3e3' => 'filter_vintage',
        'mdi-e880' => 'find_in_page',
        'mdi-e881' => 'find_replace',
        'mdi-e90d' => 'fingerprint',
        'mdi-e5dc' => 'first_page',
        'mdi-eb43' => 'fitness_center',
        'mdi-e153' => 'flag',
        'mdi-e3e4' => 'flare',
        'mdi-e3e5' => 'flash_auto',
        'mdi-e3e6' => 'flash_off',
        'mdi-e3e7' => 'flash_on',
        'mdi-e539' => 'flight',
        'mdi-e904' => 'flight_land',
        'mdi-e905' => 'flight_takeoff',
        'mdi-e3e8' => 'flip',
        'mdi-e882' => 'flip_to_back',
        'mdi-e883' => 'flip_to_front',
        'mdi-e2c7' => 'folder',
        'mdi-e2c8' => 'folder_open',
        'mdi-e2c9' => 'folder_shared',
        'mdi-e617' => 'folder_special',
        'mdi-e167' => 'font_download',
        'mdi-e234' => 'format_align_center',
        'mdi-e235' => 'format_align_justify',
        'mdi-e236' => 'format_align_left',
        'mdi-e237' => 'format_align_right',
        'mdi-e238' => 'format_bold',
        'mdi-e239' => 'format_clear',
        'mdi-e23a' => 'format_color_fill',
        'mdi-e23b' => 'format_color_reset',
        'mdi-e23c' => 'format_color_text',
        'mdi-e23d' => 'format_indent_decrease',
        'mdi-e23e' => 'format_indent_increase',
        'mdi-e23f' => 'format_italic',
        'mdi-e240' => 'format_line_spacing',
        'mdi-e241' => 'format_list_bulleted',
        'mdi-e242' => 'format_list_numbered',
        'mdi-e243' => 'format_paint',
        'mdi-e244' => 'format_quote',
        'mdi-e25e' => 'format_shapes',
        'mdi-e245' => 'format_size',
        'mdi-e246' => 'format_strikethrough',
        'mdi-e247' => 'format_textdirection_l_to_r',
        'mdi-e248' => 'format_textdirection_r_to_l',
        'mdi-e249' => 'format_underlined',
        'mdi-e0bf' => 'forum',
        'mdi-e154' => 'forward',
        'mdi-e056' => 'forward_10',
        'mdi-e057' => 'forward_30',
        'mdi-e058' => 'forward_5',
        'mdi-eb44' => 'free_breakfast',
        'mdi-e5d0' => 'fullscreen',
        'mdi-e5d1' => 'fullscreen_exit',
        'mdi-e24a' => 'functions',
        'mdi-e927' => 'g_translate',
        'mdi-e30f' => 'gamepad',
        'mdi-e021' => 'games',
        'mdi-e90e' => 'gavel',
        'mdi-e155' => 'gesture',
        'mdi-e884' => 'get_app',
        'mdi-e908' => 'gif',
        'mdi-eb45' => 'golf_course',
        'mdi-e1b3' => 'gps_fixed',
        'mdi-e1b4' => 'gps_not_fixed',
        'mdi-e1b5' => 'gps_off',
        'mdi-e885' => 'grade',
        'mdi-e3e9' => 'gradient',
        'mdi-e3ea' => 'grain',
        'mdi-e1b8' => 'graphic_eq',
        'mdi-e3eb' => 'grid_off',
        'mdi-e3ec' => 'grid_on',
        'mdi-e7ef' => 'group',
        'mdi-e7f0' => 'group_add',
        'mdi-e886' => 'group_work',
        'mdi-e052' => 'hd',
        'mdi-e3ed' => 'hdr_off',
        'mdi-e3ee' => 'hdr_on',
        'mdi-e3f1' => 'hdr_strong',
        'mdi-e3f2' => 'hdr_weak',
        'mdi-e310' => 'headset',
        'mdi-e311' => 'headset_mic',
        'mdi-e3f3' => 'healing',
        'mdi-e023' => 'hearing',
        'mdi-e887' => 'help',
        'mdi-e8fd' => 'help_outline',
        'mdi-e024' => 'high_quality',
        'mdi-e25f' => 'highlight',
        'mdi-e888' => 'highlight_off',
        'mdi-e889' => 'history',
        'mdi-e88a' => 'home',
        'mdi-eb46' => 'hot_tub',
        'mdi-e53a' => 'hotel',
        'mdi-e88b' => 'hourglass_empty',
        'mdi-e88c' => 'hourglass_full',
        'mdi-e902' => 'http',
        'mdi-e88d' => 'https',
        'mdi-e3f4' => 'image',
        'mdi-e3f5' => 'image_aspect_ratio',
        'mdi-e0e0' => 'import_contacts',
        'mdi-e0c3' => 'import_export',
        'mdi-e912' => 'important_devices',
        'mdi-e156' => 'inbox',
        'mdi-e909' => 'indeterminate_check_box',
        'mdi-e88e' => 'info',
        'mdi-e88f' => 'info_outline',
        'mdi-e890' => 'input',
        'mdi-e24b' => 'insert_chart',
        'mdi-e24c' => 'insert_comment',
        'mdi-e24d' => 'insert_drive_file',
        'mdi-e24e' => 'insert_emoticon',
        'mdi-e24f' => 'insert_invitation',
        'mdi-e250' => 'insert_link',
        'mdi-e251' => 'insert_photo',
        'mdi-e891' => 'invert_colors',
        'mdi-e0c4' => 'invert_colors_off',
        'mdi-e3f6' => 'iso',
        'mdi-e312' => 'keyboard',
        'mdi-e313' => 'keyboard_arrow_down',
        'mdi-e314' => 'keyboard_arrow_left',
        'mdi-e315' => 'keyboard_arrow_right',
        'mdi-e316' => 'keyboard_arrow_up',
        'mdi-e317' => 'keyboard_backspace',
        'mdi-e318' => 'keyboard_capslock',
        'mdi-e31a' => 'keyboard_hide',
        'mdi-e31b' => 'keyboard_return',
        'mdi-e31c' => 'keyboard_tab',
        'mdi-e31d' => 'keyboard_voice',
        'mdi-eb47' => 'kitchen',
        'mdi-e892' => 'label',
        'mdi-e893' => 'label_outline',
        'mdi-e3f7' => 'landscape',
        'mdi-e894' => 'language',
        'mdi-e31e' => 'laptop',
        'mdi-e31f' => 'laptop_chromebook',
        'mdi-e320' => 'laptop_mac',
        'mdi-e321' => 'laptop_windows',
        'mdi-e5dd' => 'last_page',
        'mdi-e895' => 'launch',
        'mdi-e53b' => 'layers',
        'mdi-e53c' => 'layers_clear',
        'mdi-e3f8' => 'leak_add',
        'mdi-e3f9' => 'leak_remove',
        'mdi-e3fa' => 'lens',
        'mdi-e02e' => 'library_add',
        'mdi-e02f' => 'library_books',
        'mdi-e030' => 'library_music',
        'mdi-e90f' => 'lightbulb_outline',
        'mdi-e919' => 'line_style',
        'mdi-e91a' => 'line_weight',
        'mdi-e260' => 'linear_scale',
        'mdi-e157' => 'link',
        'mdi-e438' => 'linked_camera',
        'mdi-e896' => 'list',
        'mdi-e0c6' => 'live_help',
        'mdi-e639' => 'live_tv',
        'mdi-e53f' => 'local_activity',
        'mdi-e53d' => 'local_airport',
        'mdi-e53e' => 'local_atm',
        'mdi-e540' => 'local_bar',
        'mdi-e541' => 'local_cafe',
        'mdi-e542' => 'local_car_wash',
        'mdi-e543' => 'local_convenience_store',
        'mdi-e556' => 'local_dining',
        'mdi-e544' => 'local_drink',
        'mdi-e545' => 'local_florist',
        'mdi-e546' => 'local_gas_station',
        'mdi-e547' => 'local_grocery_store',
        'mdi-e548' => 'local_hospital',
        'mdi-e549' => 'local_hotel',
        'mdi-e54a' => 'local_laundry_service',
        'mdi-e54b' => 'local_library',
        'mdi-e54c' => 'local_mall',
        'mdi-e54d' => 'local_movies',
        'mdi-e54e' => 'local_offer',
        'mdi-e54f' => 'local_parking',
        'mdi-e550' => 'local_pharmacy',
        'mdi-e551' => 'local_phone',
        'mdi-e552' => 'local_pizza',
        'mdi-e553' => 'local_play',
        'mdi-e554' => 'local_post_office',
        'mdi-e555' => 'local_printshop',
        'mdi-e557' => 'local_see',
        'mdi-e558' => 'local_shipping',
        'mdi-e559' => 'local_taxi',
        'mdi-e7f1' => 'location_city',
        'mdi-e1b6' => 'location_disabled',
        'mdi-e0c7' => 'location_off',
        'mdi-e0c8' => 'location_on',
        'mdi-e1b7' => 'location_searching',
        'mdi-e897' => 'lock',
        'mdi-e898' => 'lock_open',
        'mdi-e899' => 'lock_outline',
        'mdi-e3fc' => 'looks',
        'mdi-e3fb' => 'looks_3',
        'mdi-e3fd' => 'looks_4',
        'mdi-e3fe' => 'looks_5',
        'mdi-e3ff' => 'looks_6',
        'mdi-e400' => 'looks_one',
        'mdi-e401' => 'looks_two',
        'mdi-e028' => 'loop',
        'mdi-e402' => 'loupe',
        'mdi-e16d' => 'low_priority',
        'mdi-e89a' => 'loyalty',
        'mdi-e158' => 'mail',
        'mdi-e0e1' => 'mail_outline',
        'mdi-e55b' => 'map',
        'mdi-e159' => 'markunread',
        'mdi-e89b' => 'markunread_mailbox',
        'mdi-e322' => 'memory',
        'mdi-e5d2' => 'menu',
        'mdi-e252' => 'merge_type',
        'mdi-e0c9' => 'message',
        'mdi-e029' => 'mic',
        'mdi-e02a' => 'mic_none',
        'mdi-e02b' => 'mic_off',
        'mdi-e618' => 'mms',
        'mdi-e253' => 'mode_comment',
        'mdi-e254' => 'mode_edit',
        'mdi-e263' => 'monetization_on',
        'mdi-e25c' => 'money_off',
        'mdi-e403' => 'monochrome_photos',
        'mdi-e7f2' => 'mood',
        'mdi-e7f3' => 'mood_bad',
        'mdi-e619' => 'more',
        'mdi-e5d3' => 'more_horiz',
        'mdi-e5d4' => 'more_vert',
        'mdi-e91b' => 'motorcycle',
        'mdi-e323' => 'mouse',
        'mdi-e168' => 'move_to_inbox',
        'mdi-e02c' => 'movie',
        'mdi-e404' => 'movie_creation',
        'mdi-e43a' => 'movie_filter',
        'mdi-e6df' => 'multiline_chart',
        'mdi-e405' => 'music_note',
        'mdi-e063' => 'music_video',
        'mdi-e55c' => 'my_location',
        'mdi-e406' => 'nature',
        'mdi-e407' => 'nature_people',
        'mdi-e408' => 'navigate_before',
        'mdi-e409' => 'navigate_next',
        'mdi-e55d' => 'navigation',
        'mdi-e569' => 'near_me',
        'mdi-e1b9' => 'network_cell',
        'mdi-e640' => 'network_check',
        'mdi-e61a' => 'network_locked',
        'mdi-e1ba' => 'network_wifi',
        'mdi-e031' => 'new_releases',
        'mdi-e16a' => 'next_week',
        'mdi-e1bb' => 'nfc',
        'mdi-e641' => 'no_encryption',
        'mdi-e0cc' => 'no_sim',
        'mdi-e033' => 'not_interested',
        'mdi-e06f' => 'note',
        'mdi-e89c' => 'note_add',
        'mdi-e7f4' => 'notifications',
        'mdi-e7f7' => 'notifications_active',
        'mdi-e7f5' => 'notifications_none',
        'mdi-e7f6' => 'notifications_off',
        'mdi-e7f8' => 'notifications_paused',
        'mdi-e90a' => 'offline_pin',
        'mdi-e63a' => 'ondemand_video',
        'mdi-e91c' => 'opacity',
        'mdi-e89d' => 'open_in_browser',
        'mdi-e89e' => 'open_in_new',
        'mdi-e89f' => 'open_with',
        'mdi-e7f9' => 'pages',
        'mdi-e8a0' => 'pageview',
        'mdi-e40a' => 'palette',
        'mdi-e925' => 'pan_tool',
        'mdi-e40b' => 'panorama',
        'mdi-e40c' => 'panorama_fish_eye',
        'mdi-e40d' => 'panorama_horizontal',
        'mdi-e40e' => 'panorama_vertical',
        'mdi-e40f' => 'panorama_wide_angle',
        'mdi-e7fa' => 'party_mode',
        'mdi-e034' => 'pause',
        'mdi-e035' => 'pause_circle_filled',
        'mdi-e036' => 'pause_circle_outline',
        'mdi-e8a1' => 'payment',
        'mdi-e7fb' => 'people',
        'mdi-e7fc' => 'people_outline',
        'mdi-e8a2' => 'perm_camera_mic',
        'mdi-e8a3' => 'perm_contact_calendar',
        'mdi-e8a4' => 'perm_data_setting',
        'mdi-e8a5' => 'perm_device_information',
        'mdi-e8a6' => 'perm_identity',
        'mdi-e8a7' => 'perm_media',
        'mdi-e8a8' => 'perm_phone_msg',
        'mdi-e8a9' => 'perm_scan_wifi',
        'mdi-e7fd' => 'person',
        'mdi-e7fe' => 'person_add',
        'mdi-e7ff' => 'person_outline',
        'mdi-e55a' => 'person_pin',
        'mdi-e56a' => 'person_pin_circle',
        'mdi-e63b' => 'personal_video',
        'mdi-e91d' => 'pets',
        'mdi-e0cd' => 'phone',
        'mdi-e324' => 'phone_android',
        'mdi-e61b' => 'phone_bluetooth_speaker',
        'mdi-e61c' => 'phone_forwarded',
        'mdi-e61d' => 'phone_in_talk',
        'mdi-e325' => 'phone_iphone',
        'mdi-e61e' => 'phone_locked',
        'mdi-e61f' => 'phone_missed',
        'mdi-e620' => 'phone_paused',
        'mdi-e326' => 'phonelink',
        'mdi-e0db' => 'phonelink_erase',
        'mdi-e0dc' => 'phonelink_lock',
        'mdi-e327' => 'phonelink_off',
        'mdi-e0dd' => 'phonelink_ring',
        'mdi-e0de' => 'phonelink_setup',
        'mdi-e410' => 'photo',
        'mdi-e411' => 'photo_album',
        'mdi-e412' => 'photo_camera',
        'mdi-e43b' => 'photo_filter',
        'mdi-e413' => 'photo_library',
        'mdi-e432' => 'photo_size_select_actual',
        'mdi-e433' => 'photo_size_select_large',
        'mdi-e434' => 'photo_size_select_small',
        'mdi-e415' => 'picture_as_pdf',
        'mdi-e8aa' => 'picture_in_picture',
        'mdi-e911' => 'picture_in_picture_alt',
        'mdi-e6c4' => 'pie_chart',
        'mdi-e6c5' => 'pie_chart_outlined',
        'mdi-e55e' => 'pin_drop',
        'mdi-e55f' => 'place',
        'mdi-e037' => 'play_arrow',
        'mdi-e038' => 'play_circle_filled',
        'mdi-e039' => 'play_circle_outline',
        'mdi-e906' => 'play_for_work',
        'mdi-e03b' => 'playlist_add',
        'mdi-e065' => 'playlist_add_check',
        'mdi-e05f' => 'playlist_play',
        'mdi-e800' => 'plus_one',
        'mdi-e801' => 'poll',
        'mdi-e8ab' => 'polymer',
        'mdi-eb48' => 'pool',
        'mdi-e0ce' => 'portable_wifi_off',
        'mdi-e416' => 'portrait',
        'mdi-e63c' => 'power',
        'mdi-e336' => 'power_input',
        'mdi-e8ac' => 'power_settings_new',
        'mdi-e91e' => 'pregnant_woman',
        'mdi-e0df' => 'present_to_all',
        'mdi-e8ad' => 'print',
        'mdi-e645' => 'priority_high',
        'mdi-e80b' => 'public',
        'mdi-e255' => 'publish',
        'mdi-e8ae' => 'query_builder',
        'mdi-e8af' => 'question_answer',
        'mdi-e03c' => 'queue',
        'mdi-e03d' => 'queue_music',
        'mdi-e066' => 'queue_play_next',
        'mdi-e03e' => 'radio',
        'mdi-e837' => 'radio_button_checked',
        'mdi-e836' => 'radio_button_unchecked',
        'mdi-e560' => 'rate_review',
        'mdi-e8b0' => 'receipt',
        'mdi-e03f' => 'recent_actors',
        'mdi-e91f' => 'record_voice_over',
        'mdi-e8b1' => 'redeem',
        'mdi-e15a' => 'redo',
        'mdi-e5d5' => 'refresh',
        'mdi-e15b' => 'remove',
        'mdi-e15c' => 'remove_circle',
        'mdi-e15d' => 'remove_circle_outline',
        'mdi-e067' => 'remove_from_queue',
        'mdi-e417' => 'remove_red_eye',
        'mdi-e928' => 'remove_shopping_cart',
        'mdi-e8fe' => 'reorder',
        'mdi-e040' => 'repeat',
        'mdi-e041' => 'repeat_one',
        'mdi-e042' => 'replay',
        'mdi-e059' => 'replay_10',
        'mdi-e05a' => 'replay_30',
        'mdi-e05b' => 'replay_5',
        'mdi-e15e' => 'reply',
        'mdi-e15f' => 'reply_all',
        'mdi-e160' => 'report',
        'mdi-e8b2' => 'report_problem',
        'mdi-e56c' => 'restaurant',
        'mdi-e561' => 'restaurant_menu',
        'mdi-e8b3' => 'restore',
        'mdi-e929' => 'restore_page',
        'mdi-e0d1' => 'ring_volume',
        'mdi-e8b4' => 'room',
        'mdi-eb49' => 'room_service',
        'mdi-e418' => 'rotate_90_degrees_ccw',
        'mdi-e419' => 'rotate_left',
        'mdi-e41a' => 'rotate_right',
        'mdi-e920' => 'rounded_corner',
        'mdi-e328' => 'router',
        'mdi-e921' => 'rowing',
        'mdi-e0e5' => 'rss_feed',
        'mdi-e642' => 'rv_hookup',
        'mdi-e562' => 'satellite',
        'mdi-e161' => 'save',
        'mdi-e329' => 'scanner',
        'mdi-e8b5' => 'schedule',
        'mdi-e80c' => 'school',
        'mdi-e1be' => 'screen_lock_landscape',
        'mdi-e1bf' => 'screen_lock_portrait',
        'mdi-e1c0' => 'screen_lock_rotation',
        'mdi-e1c1' => 'screen_rotation',
        'mdi-e0e2' => 'screen_share',
        'mdi-e623' => 'sd_card',
        'mdi-e1c2' => 'sd_storage',
        'mdi-e8b6' => 'search',
        'mdi-e32a' => 'security',
        'mdi-e162' => 'select_all',
        'mdi-e163' => 'send',
        'mdi-e811' => 'sentiment_dissatisfied',
        'mdi-e812' => 'sentiment_neutral',
        'mdi-e813' => 'sentiment_satisfied',
        'mdi-e814' => 'sentiment_very_dissatisfied',
        'mdi-e815' => 'sentiment_very_satisfied',
        'mdi-e8b8' => 'settings',
        'mdi-e8b9' => 'settings_applications',
        'mdi-e8ba' => 'settings_backup_restore',
        'mdi-e8bb' => 'settings_bluetooth',
        'mdi-e8bd' => 'settings_brightness',
        'mdi-e8bc' => 'settings_cell',
        'mdi-e8be' => 'settings_ethernet',
        'mdi-e8bf' => 'settings_input_antenna',
        'mdi-e8c0' => 'settings_input_component',
        'mdi-e8c1' => 'settings_input_composite',
        'mdi-e8c2' => 'settings_input_hdmi',
        'mdi-e8c3' => 'settings_input_svideo',
        'mdi-e8c4' => 'settings_overscan',
        'mdi-e8c5' => 'settings_phone',
        'mdi-e8c6' => 'settings_power',
        'mdi-e8c7' => 'settings_remote',
        'mdi-e1c3' => 'settings_system_daydream',
        'mdi-e8c8' => 'settings_voice',
        'mdi-e80d' => 'share',
        'mdi-e8c9' => 'shop',
        'mdi-e8ca' => 'shop_two',
        'mdi-e8cb' => 'shopping_basket',
        'mdi-e8cc' => 'shopping_cart',
        'mdi-e261' => 'short_text',
        'mdi-e6e1' => 'show_chart',
        'mdi-e043' => 'shuffle',
        'mdi-e1c8' => 'signal_cellular_4_bar',
        'mdi-e1cd' => 'signal_cellular_connected_no_internet_4_bar',
        'mdi-e1ce' => 'signal_cellular_no_sim',
        'mdi-e1cf' => 'signal_cellular_null',
        'mdi-e1d0' => 'signal_cellular_off',
        'mdi-e1d8' => 'signal_wifi_4_bar',
        'mdi-e1d9' => 'signal_wifi_4_bar_lock',
        'mdi-e1da' => 'signal_wifi_off',
        'mdi-e32b' => 'sim_card',
        'mdi-e624' => 'sim_card_alert',
        'mdi-e044' => 'skip_next',
        'mdi-e045' => 'skip_previous',
        'mdi-e41b' => 'slideshow',
        'mdi-e068' => 'slow_motion_video',
        'mdi-e32c' => 'smartphone',
        'mdi-eb4a' => 'smoke_free',
        'mdi-eb4b' => 'smoking_rooms',
        'mdi-e625' => 'sms',
        'mdi-e626' => 'sms_failed',
        'mdi-e046' => 'snooze',
        'mdi-e164' => 'sort',
        'mdi-e053' => 'sort_by_alpha',
        'mdi-eb4c' => 'spa',
        'mdi-e256' => 'space_bar',
        'mdi-e32d' => 'speaker',
        'mdi-e32e' => 'speaker_group',
        'mdi-e8cd' => 'speaker_notes',
        'mdi-e92a' => 'speaker_notes_off',
        'mdi-e0d2' => 'speaker_phone',
        'mdi-e8ce' => 'spellcheck',
        'mdi-e838' => 'star',
        'mdi-e83a' => 'star_border',
        'mdi-e839' => 'star_half',
        'mdi-e8d0' => 'stars',
        'mdi-e0d3' => 'stay_current_landscape',
        'mdi-e0d4' => 'stay_current_portrait',
        'mdi-e0d5' => 'stay_primary_landscape',
        'mdi-e0d6' => 'stay_primary_portrait',
        'mdi-e047' => 'stop',
        'mdi-e0e3' => 'stop_screen_share',
        'mdi-e1db' => 'storage',
        'mdi-e8d1' => 'store',
        'mdi-e563' => 'store_mall_directory',
        'mdi-e41c' => 'straighten',
        'mdi-e56e' => 'streetview',
        'mdi-e257' => 'strikethrough_s',
        'mdi-e41d' => 'style',
        'mdi-e5d9' => 'subdirectory_arrow_left',
        'mdi-e5da' => 'subdirectory_arrow_right',
        'mdi-e8d2' => 'subject',
        'mdi-e064' => 'subscriptions',
        'mdi-e048' => 'subtitles',
        'mdi-e56f' => 'subway',
        'mdi-e8d3' => 'supervisor_account',
        'mdi-e049' => 'surround_sound',
        'mdi-e0d7' => 'swap_calls',
        'mdi-e8d4' => 'swap_horiz',
        'mdi-e8d5' => 'swap_vert',
        'mdi-e8d6' => 'swap_vertical_circle',
        'mdi-e41e' => 'switch_camera',
        'mdi-e41f' => 'switch_video',
        'mdi-e627' => 'sync',
        'mdi-e628' => 'sync_disabled',
        'mdi-e629' => 'sync_problem',
        'mdi-e62a' => 'system_update',
        'mdi-e8d7' => 'system_update_alt',
        'mdi-e8d8' => 'tab',
        'mdi-e8d9' => 'tab_unselected',
        'mdi-e32f' => 'tablet',
        'mdi-e330' => 'tablet_android',
        'mdi-e331' => 'tablet_mac',
        'mdi-e420' => 'tag_faces',
        'mdi-e62b' => 'tap_and_play',
        'mdi-e564' => 'terrain',
        'mdi-e262' => 'text_fields',
        'mdi-e165' => 'text_format',
        'mdi-e0d8' => 'textsms',
        'mdi-e421' => 'texture',
        'mdi-e8da' => 'theaters',
        'mdi-e8db' => 'thumb_down',
        'mdi-e8dc' => 'thumb_up',
        'mdi-e8dd' => 'thumbs_up_down',
        'mdi-e62c' => 'time_to_leave',
        'mdi-e422' => 'timelapse',
        'mdi-e922' => 'timeline',
        'mdi-e425' => 'timer',
        'mdi-e423' => 'timer_10',
        'mdi-e424' => 'timer_3',
        'mdi-e426' => 'timer_off',
        'mdi-e264' => 'title',
        'mdi-e8de' => 'toc',
        'mdi-e8df' => 'today',
        'mdi-e8e0' => 'toll',
        'mdi-e427' => 'tonality',
        'mdi-e913' => 'touch_app',
        'mdi-e332' => 'toys',
        'mdi-e8e1' => 'track_changes',
        'mdi-e565' => 'traffic',
        'mdi-e570' => 'train',
        'mdi-e571' => 'tram',
        'mdi-e572' => 'transfer_within_a_station',
        'mdi-e428' => 'transform',
        'mdi-e8e2' => 'translate',
        'mdi-e8e3' => 'trending_down',
        'mdi-e8e4' => 'trending_flat',
        'mdi-e8e5' => 'trending_up',
        'mdi-e429' => 'tune',
        'mdi-e8e6' => 'turned_in',
        'mdi-e8e7' => 'turned_in_not',
        'mdi-e333' => 'tv',
        'mdi-e169' => 'unarchive',
        'mdi-e166' => 'undo',
        'mdi-e5d6' => 'unfold_less',
        'mdi-e5d7' => 'unfold_more',
        'mdi-e923' => 'update',
        'mdi-e1e0' => 'usb',
        'mdi-e8e8' => 'verified_user',
        'mdi-e258' => 'vertical_align_bottom',
        'mdi-e259' => 'vertical_align_center',
        'mdi-e25a' => 'vertical_align_top',
        'mdi-e62d' => 'vibration',
        'mdi-e070' => 'video_call',
        'mdi-e071' => 'video_label',
        'mdi-e04a' => 'video_library',
        'mdi-e04b' => 'videocam',
        'mdi-e04c' => 'videocam_off',
        'mdi-e338' => 'videogame_asset',
        'mdi-e8e9' => 'view_agenda',
        'mdi-e8ea' => 'view_array',
        'mdi-e8eb' => 'view_carousel',
        'mdi-e8ec' => 'view_column',
        'mdi-e42a' => 'view_comfy',
        'mdi-e42b' => 'view_compact',
        'mdi-e8ed' => 'view_day',
        'mdi-e8ee' => 'view_headline',
        'mdi-e8ef' => 'view_list',
        'mdi-e8f0' => 'view_module',
        'mdi-e8f1' => 'view_quilt',
        'mdi-e8f2' => 'view_stream',
        'mdi-e8f3' => 'view_week',
        'mdi-e435' => 'vignette',
        'mdi-e8f4' => 'visibility',
        'mdi-e8f5' => 'visibility_off',
        'mdi-e62e' => 'voice_chat',
        'mdi-e0d9' => 'voicemail',
        'mdi-e04d' => 'volume_down',
        'mdi-e04e' => 'volume_mute',
        'mdi-e04f' => 'volume_off',
        'mdi-e050' => 'volume_up',
        'mdi-e0da' => 'vpn_key',
        'mdi-e62f' => 'vpn_lock',
        'mdi-e1bc' => 'wallpaper',
        'mdi-e002' => 'warning',
        'mdi-e334' => 'watch',
        'mdi-e924' => 'watch_later',
        'mdi-e42c' => 'wb_auto',
        'mdi-e42d' => 'wb_cloudy',
        'mdi-e42e' => 'wb_incandescent',
        'mdi-e436' => 'wb_iridescent',
        'mdi-e430' => 'wb_sunny',
        'mdi-e63d' => 'wc',
        'mdi-e051' => 'web',
        'mdi-e069' => 'web_asset',
        'mdi-e16b' => 'weekend',
        'mdi-e80e' => 'whatshot',
        'mdi-e1bd' => 'widgets',
        'mdi-e63e' => 'wifi',
        'mdi-e1e1' => 'wifi_lock',
        'mdi-e1e2' => 'wifi_tethering',
        'mdi-e8f9' => 'work',
        'mdi-e25b' => 'wrap_text',
        'mdi-e8fa' => 'youtube_searched_for',
        'mdi-e8ff' => 'zoom_in',
        'mdi-e900' => 'zoom_out',
        'mdi-e56b' => 'zoom_out_map',
    );

    $mdi = apply_filters( "rmp_mdi", $mdi );
    krsort( $mdi );

    return $mdi;
}

function rmp_get_fa_icons() {
    $arrContextOptions = array(
        "ssl" => array(
            "verify_peer"      => false,
            "verify_peer_name" => false,
        ),
    );
    $file = file_get_contents('https://raw.githubusercontent.com/FortAwesome/Font-Awesome/master/metadata/icons.json', false, stream_context_create($arrContextOptions));
    $json_object = json_decode($file );

    return $json_object;
}


/**
 * Get default options.
 * @since 4.0.0
 *
 * @return array default_options list of option with default value.
 */
function rmp_get_default_options() {

    $default_options = array(
        'menu_theme'                                       => 'Default',
        'theme_type'                                       => 'default',
        'theme_location_menu'                              => '0',
        'submenu_submenu_arrow_width'                      => '40',
        'submenu_submenu_arrow_width_unit'                 => 'px',
        'submenu_submenu_arrow_height'                     => '39',
        'submenu_submenu_arrow_height_unit'                => 'px',
        'submenu_arrow_position'                           => 'right',
        'submenu_sub_arrow_background_colour'              => '',
        'submenu_sub_arrow_background_hover_colour'        => '',
        'submenu_sub_arrow_background_colour_active'       => '',
        'submenu_sub_arrow_background_hover_colour_active' => '',
        'submenu_sub_arrow_border_width'                   => '',
        'submenu_sub_arrow_border_width_unit'              => 'px',
        'submenu_sub_arrow_border_colour'                  => '#1d4354',
        'submenu_sub_arrow_border_hover_colour'            => '#3f3f3f',
        'submenu_sub_arrow_border_colour_active'           => '#1d4354',
        'submenu_sub_arrow_border_hover_colour_active'     => '#3f3f3f',
        'submenu_sub_arrow_shape_colour'                   => '#fff',
        'submenu_sub_arrow_shape_hover_colour'             => '#fff',
        'submenu_sub_arrow_shape_colour_active'            => '#fff',
        'submenu_sub_arrow_shape_hover_colour_active'      => '#fff',
        'use_header_bar'                                   => 'off',
        'header_bar_items_order'                           =>
          array(
              'logo'               => 'off',
              'title'              => 'on',
              'additional content' => 'off',
              'menu'               => 'on',
              'search'             => 'off',
          ),
        'header_bar_title'                                 => 'Responsive Menu',
        'header_bar_html_content'                          => '',
        'header_bar_logo'                                  => '',
        'header_bar_logo_link'                             => '',
        'header_bar_logo_width'                            => '',
        'header_bar_logo_width_unit'                       => '%',
        'header_bar_logo_height'                           => '',
        'header_bar_logo_height_unit'                      => 'px',
        'header_bar_height'                                => '80',
        'header_bar_height_unit'                           => 'px',
        'header_bar_padding'                               =>
          array(
              'top'    => '0px',
              'right'  => '5%',
              'bottom' => '0px',
              'left'   => '5%',
          ),
        'header_bar_font'                                  => '',
        'header_bar_font_size'                             => '14',
        'header_bar_font_size_unit'                        => 'px',
        'header_bar_text_color'                            => '#ffffff',
        'header_bar_background_color'                      => '#1d4354',
        'header_bar_breakpoint'                            => '8000',
        'header_bar_position_type'                         => 'fixed',
        'header_bar_adjust_page'                           => 'on',
        'header_bar_scroll_enable'                         => 'off',
        'header_bar_scroll_background_color'               => '#36bdf6',
        'mobile_breakpoint'                                => '600',
        'tablet_breakpoint'                                => '1024',
        'transition_speed'                                 => '0.5',
        'sub_menu_speed'                                   => '0.2',
        'show_menu_on_page_load'                           => 'off',
        'menu_disable_scrolling'                           => 'off',
        'menu_overlay'                                     => 'off',
        'menu_overlay_colour'                              => 'rgba(0,0,0,0.7)',
        'desktop_menu_width'                               => '',
        'desktop_menu_width_unit'                          => '%',
        'desktop_menu_positioning'                         => 'absolute',
        'desktop_menu_side'                                => 'left',
        'desktop_menu_content_alignment'                   => 'left',
        'desktop_menu_to_hide'                             => '',
        'use_current_theme_location'                       => 'off',
        'mega_menu'                                        =>
          array(
              225 => 'off',
              227 => 'off',
              229 => 'off',
              228 => 'off',
              226 => 'off',
          ),
        'desktop_submenu_open_animation'                   => 'none',
        'desktop_submenu_open_animation_speed'             => '100ms',
        'desktop_submenu_open_on_click'                    => 'off',
        'desktop_menu_hide_and_show'                       => 'off',
        'menu_name'                                        => 'Primary Menu',
        'menu_to_use'                                      => 'main-menu',
        'different_menu_for_mobile'                        => 'off',
        'menu_to_use_in_mobile'                            => 'main-menu',
        'use_mobile_menu'                                  => 'on',
        'use_tablet_menu'                                  => 'on',
        'use_desktop_menu'                                 => 'on',
        'menu_display_on'                                  => 'all-pages',
        'menu_to_hide'                                     => '',
        'submenu_descriptions_on'                          => 'off',
        'custom_walker'                                    => '',
        'menu_background_colour'                           => '',
        'menu_depth'                                       => '5',
        'smooth_scroll_on'                                 => 'off',
        'smooth_scroll_speed'                              => '500',
        'menu_font_icons'                                  =>
          array(
              'id'   =>
              array(
				  0 => '225',
              ),
              'icon' =>
              array(
				  0 => '',
              ),
          ),
        'menu_links_height'                                => '40',
        'menu_links_height_unit'                           => 'px',
        'menu_links_line_height'                           => '40',
        'menu_links_line_height_unit'                      => 'px',
        'menu_depth_0'                                     => '5',
        'menu_depth_0_unit'                                => '%',
        'menu_font_size'                                   => '15',
        'menu_font_size_unit'                              => 'px',
        'menu_font'                                        => '',
        'menu_font_weight'                                 => 'normal',
        'menu_text_alignment'                              => 'left',
        'menu_text_letter_spacing'                         => '',
        'menu_word_wrap'                                   => 'off',
        'menu_link_colour'                                 => '#fff',
        'menu_link_hover_colour'                           => '#fff',
        'menu_current_link_colour'                         => '#fff',
        'menu_current_link_hover_colour'                   => '#fff',
        'menu_parent_link_active_color'                    => '',
        'menu_parent_link_background_active_color'         => '',
        'menu_item_background_colour'                      => '',
        'menu_item_background_hover_colour'                => '',
        'menu_current_item_background_colour'              => '#6fda44',
        'menu_current_item_background_hover_colour'        => '',
        'menu_border_width'                                => '',
        'menu_border_width_unit'                           => 'px',
        'menu_item_border_colour'                          => '#1d4354',
        'menu_item_border_colour_hover'                    => '#1d4354',
        'menu_current_item_border_colour'                  => '#1d4354',
        'menu_current_item_border_hover_colour'            => '#3f3f3f',
        'submenu_links_height'                             => '40',
        'submenu_links_height_unit'                        => 'px',
        'submenu_links_line_height'                        => '40',
        'submenu_links_line_height_unit'                   => 'px',
        'menu_depth_side'                                  => 'left',
        'menu_depth_1'                                     => '10',
        'menu_depth_1_unit'                                => '%',
        'menu_depth_2'                                     => '15',
        'menu_depth_2_unit'                                => '%',
        'menu_depth_3'                                     => '20',
        'menu_depth_3_unit'                                => '%',
        'menu_depth_4'                                     => '25',
        'menu_depth_4_unit'                                => '%',
        'submenu_item_background_colour'                   => '',
        'submenu_item_background_hover_colour'             => '',
        'submenu_current_item_background_colour'           => '',
        'submenu_current_item_background_hover_colour'     => '',
        'submenu_border_width'                             => '',
        'submenu_border_width_unit'                        => 'px',
        'submenu_item_border_colour'                       => '#1d4354',
        'submenu_item_border_colour_hover'                 => '#1d4354',
        'submenu_current_item_border_colour'               => '#1d4354',
        'submenu_current_item_border_hover_colour'         => '#3f3f3f',
        'submenu_font_size'                                => '13',
        'submenu_font_size_unit'                           => 'px',
        'submenu_font'                                     => '',
        'submenu_font_weight'                              => 'normal',
        'submenu_text_letter_spacing'                      => '',
        'submenu_text_alignment'                           => 'left',
        'submenu_link_colour'                              => '#fff',
        'submenu_link_hover_colour'                        => '#fff',
        'submenu_current_link_colour'                      => '#fff',
        'submenu_current_link_hover_colour'                => '#fff',
        'inactive_arrow_shape'                             => '▼',
        'active_arrow_shape'                               => '▲',
        'inactive_arrow_font_icon'                         => '',
        'active_arrow_font_icon'                           => '',
        'inactive_arrow_image'                             => '',
        'active_arrow_image'                               => '',
        'submenu_arrow_width'                              => '40',
        'submenu_arrow_width_unit'                         => 'px',
        'submenu_arrow_height'                             => '39',
        'submenu_arrow_height_unit'                        => 'px',
        'arrow_position'                                   => 'right',
        'menu_sub_arrow_shape_colour'                      => '#fff',
        'menu_sub_arrow_shape_hover_colour'                => '#fff',
        'menu_sub_arrow_shape_colour_active'               => '#fff',
        'menu_sub_arrow_shape_hover_colour_active'         => '#fff',
        'menu_sub_arrow_border_width'                      => '',
        'menu_sub_arrow_border_width_unit'                 => 'px',
        'menu_sub_arrow_border_colour'                     => '#1d4354',
        'menu_sub_arrow_border_hover_colour'               => '#3f3f3f',
        'menu_sub_arrow_border_colour_active'              => '#1d4354',
        'menu_sub_arrow_border_hover_colour_active'        => '#3f3f3f',
        'menu_sub_arrow_background_colour'                 => '',
        'menu_sub_arrow_background_hover_colour'           => '',
        'menu_sub_arrow_background_colour_active'          => 'rgba(33,33,33,0.01)',
        'menu_sub_arrow_background_hover_colour_active'    => '',
        'fade_submenus'                                    => 'off',
        'fade_submenus_side'                               => 'left',
        'fade_submenus_delay'                              => '100',
        'fade_submenus_speed'                              => '500',
        'use_slide_effect'                                 => 'off',
        'slide_effect_back_to_text'                        => 'Back',
        'accordion_animation'                              => 'off',
        'auto_expand_all_submenus'                         => 'off',
        'auto_expand_current_submenus'                     => 'off',
        'menu_item_click_to_trigger_submenu'               => 'off',
        'button_width'                                     => '55',
        'button_width_unit'                                => 'px',
        'button_height'                                    => '55',
        'button_height_unit'                               => 'px',
        'button_background_colour'                         => '#1d4354',
        'button_background_colour_hover'                   => '#1d4354',
        'button_background_colour_active'                  => '#6fda44',
        'toggle_button_border_radius'                      => '5',
        'button_transparent_background'                    => 'off',
        'button_left_or_right'                             => 'right',
        'button_position_type'                             => 'fixed',
        'button_distance_from_side'                        => '5',
        'button_distance_from_side_unit'                   => '%',
        'button_top'                                       => '15',
        'button_top_unit'                                  => 'px',
        'button_push_with_animation'                       => 'off',
        'button_click_animation'                           => 'boring',
        'button_line_margin'                               => '10',
        'button_line_margin_unit'                          => 'px',
        'button_line_width'                                => '25',
        'button_line_width_unit'                           => 'px',
        'button_line_height'                               => '3',
        'button_line_height_unit'                          => 'px',
        'button_line_colour'                               => '#fff',
        'button_line_colour_hover'                         => '#fff',
        'button_line_colour_active'                        => '#fff',
        'button_font_icon'                                 => '',
        'button_font_icon_when_clicked'                    => '',
        'button_image'                                     => '',
        'button_image_when_clicked'                        => '',
        'button_title'                                     => '',
        'button_title_open'                                => '',
        'button_title_position'                            => 'left',
        'menu_container_columns'                           => '',
        'button_font'                                      => '',
        'button_font_size'                                 => '14',
        'button_font_size_unit'                            => 'px',
        'button_title_line_height'                         => '13',
        'button_title_line_height_unit'                    => 'px',
        'button_text_colour'                               => '#fff',
        'button_trigger_type_click'                        => 'on',
        'button_trigger_type_hover'                        => 'off',
        'button_click_trigger'                             => '',
        'items_order'                                      =>
          array(
              'title'              => 'on',
              'additional content' => 'on',
              'menu'               => 'on',
              'search'             => 'on',
          ),
        'menu_title'                                       => 'Responsive Menu',
        'menu_title_link'                                  => '',
        'menu_title_link_location'                         => '_self',
        'menu_title_image'                                 => '',
        'menu_title_font_icon'                             => '',
        'menu_title_section_padding'                       =>
          array(
              'top'    => '10%',
              'right'  => '5%',
              'bottom' => '0%',
              'left'   => '5%',
          ),
        'menu_title_background_colour'                     => 'rgba(109,109,109,0)',
        'menu_title_background_hover_colour'               => 'rgba(109,109,109,0)',
        'menu_title_font_size'                             => '25',
        'menu_title_font_size_unit'                        => 'px',
        'menu_title_alignment'                             => 'center',
        'menu_title_font_weight'                           => '400',
        'menu_title_font_family'                           => '',
        'menu_title_colour'                                => '#ffffff',
        'menu_title_hover_colour'                          => '#fff',
        'menu_title_image_width'                           => '',
        'menu_title_image_width_unit'                      => '%',
        'menu_title_image_height'                          => '',
        'menu_title_image_height_unit'                     => 'px',
        'menu_additional_content'                          => 'Add more content here...',
        'menu_additional_section_padding'                  =>
          array(
              'top'    => '0%',
              'right'  => '5%',
              'bottom' => '10%',
              'left'   => '5%',
          ),
        'menu_additional_content_font_size'                => '16',
        'menu_additional_content_font_size_unit'           => 'px',
        'menu_additional_content_alignment'                => 'center',
        'menu_additional_content_colour'                   => '#6fda44',
        'menu_search_box_text'                             => 'Search',
        'menu_search_box_code'                             => '',
        'menu_search_section_padding'                      =>
          array(
              'top'    => '5%',
              'right'  => '5%',
              'bottom' => '5%',
              'left'   => '5%',
          ),
        'menu_search_box_height'                           => '45',
        'menu_search_box_height_unit'                      => 'px',
        'menu_search_box_border_radius'                    => '30',
        'menu_search_box_text_colour'                      => '#1d4354',
        'menu_search_box_background_colour'                => '#ffffff',
        'menu_search_box_placeholder_colour'               => '#1d4354',
        'menu_search_box_border_colour'                    => '',
        'menu_section_padding'                             =>
          array(
              'top'    => '0px',
              'right'  => '0px',
              'bottom' => '0px',
              'left'   => '0px',
          ),
        'menu_width'                                       => '75',
        'menu_width_unit'                                  => '%',
        'menu_maximum_width'                               => '350',
        'menu_maximum_width_unit'                          => 'px',
        'menu_minimum_width'                               => '320',
        'menu_minimum_width_unit'                          => 'px',
        'menu_auto_height'                                 => 'off',
        'menu_container_padding'                           =>
          array(
              'top'    => '0px',
              'right'  => '0px',
              'bottom' => '0px',
              'left'   => '0px',
          ),
        'menu_container_background_colour'                 => '#1d4354',
        'menu_background_image'                            => '',
        'animation_type'                                   => 'slide',
        'menu_appear_from'                                 => 'left',
        'animation_speed'                                  => '0.5',
        'page_wrapper'                                     => 'body',
        'menu_close_on_body_click'                         => 'off',
        'menu_close_on_scroll'                             => 'off',
        'menu_close_on_link_click'                         => 'off',
        'enable_touch_gestures'                            => 'off',
    );

    return $default_options;
}
